@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2003 Benedikt Meurer <benedikt.meurer@unix-ag.uni-siegen.de>
+ * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2004 Olivier Fourdan <fourdan@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -44,10 +45,9 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
-#include <libxfce4util/i18n.h>
-
-#include "xfce_marshal.h"
-#include "xfce_systemtray.h"
+#include <libxfcegui4/xfce-internals.h>
+#include <libxfcegui4/xfce_marshal.h>
+#include <libxfcegui4/xfce_systemtray.h>
 
 /* signals provided by XfceSystemTray */
 enum
@@ -138,6 +138,9 @@ xfce_system_tray_class_init (XfceSystemTrayClass * klass)
 {
     GObjectClass *gobject_class;
 
+    /* be sure to initialize the libraries i18n support first */
+    _xfce_i18n_init ();
+
     parent_class = g_type_class_peek_parent (klass);
 
     gobject_class = G_OBJECT_CLASS (klass);
@@ -221,12 +224,29 @@ xfce_system_tray_finalize (GObject * object)
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+
+/**
+ * xfce_system_tray_new:
+ * 
+ * Creates a new #XfceSystemTray object.
+ **/
 XfceSystemTray *
 xfce_system_tray_new (void)
 {
     return (g_object_new (xfce_system_tray_get_type (), NULL));
 }
 
+
+/**
+ * xfce_system_tray_register:
+ * @tray    : an #XfceSystemTray object.
+ * @xscreen : an X11 Screen object.
+ * @err     : location to store a GError object to in case of an error.
+ *
+ * Registers a system @tray for a given @xscreen.
+ *
+ * Return value: TRUE on success, else FALSE.
+ **/
 gboolean
 xfce_system_tray_register (XfceSystemTray * tray, Screen * xscreen,
                            GError ** err)
@@ -341,6 +361,13 @@ xfce_system_tray_register (XfceSystemTray * tray, Screen * xscreen,
     return (FALSE);
 }
 
+/**
+ * xfce_system_tray_unregister:
+ * @tray  : an #XfceSystemTray object.
+ *
+ * Unregisters @tray - which has been registered prior to this - from an
+ * X11 screen.
+ **/
 void
 xfce_system_tray_unregister (XfceSystemTray * tray)
 {
